# comment out if not prerelease
#define prel	rc1

%define rel	1

Summary:	Portable, fast, light and extensible IRC client
Name:		weechat
Version:	4.3.5
Release:	%mkrel %{?prel:0.%prel.}%{rel}
License:	GPLv3
Group:		Networking/IRC
Url:		https://www.weechat.org/
%if 0%{?prel:1}
Source0:	https://github.com/weechat/weechat/archive/v%{version}-%{prel}/%{name}-%{version}-%{prel}.tar.gz
%else
Source0:	https://www.weechat.org/files/src/%{name}-%{version}.tar.xz
%endif
BuildRequires:	asciidoctor
BuildRequires:	cmake
BuildRequires:	ncurses-devel
BuildRequires:	curl-devel
# need for utf8 support
BuildRequires:	ncursesw-devel
BuildRequires:	perl-devel
# Ruby & Python are really needed for the build, tks lbd
BuildRequires:	python3-devel
BuildRequires:	ruby-devel
BuildRequires:	lua-devel
BuildRequires:	aspell-devel
BuildRequires:	enchant2-devel
BuildRequires:	gettext
BuildRequires:	docbook-style-xsl
BuildRequires:	gnutls-devel
BuildRequires:	libgcrypt-devel
BuildRequires:	tcl-devel
BuildRequires:	guile3.0-devel
BuildRequires:	pkgconfig(libzstd)
BuildRequires:	pkgconfig(libcjson)
Obsoletes:	%{name}-gtk

%description
WeeChat (Wee Enhanced Environment for Chat) is a fast, light and extensible
chat client designed for many platforms.

Main features are:
- modular: a lightweight core with plugins around
- multi-protocols: IRC and Jabber (other soon)
- extensible: C plugins and scripts (Perl, Python, Ruby, Lua and Tcl)
- free software: released under GPLv3 license
- fully documented: user's guide, API, FAQ,.. translated in many languages

%files -f %{name}.lang
%doc *.html
%{_bindir}/%{name}
%{_bindir}/%{name}-curses
%{_bindir}/%{name}-headless
%{_mandir}/man1/%{name}*
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/plugins
%{_datadir}/applications/%{name}.desktop
%{_libdir}/%{name}/plugins/alias.so
%{_libdir}/%{name}/plugins/buflist.so
%{_libdir}/%{name}/plugins/exec.so
%{_libdir}/%{name}/plugins/fifo.so
%{_libdir}/%{name}/plugins/fset.so
%{_libdir}/%{name}/plugins/irc.so
%{_libdir}/%{name}/plugins/logger.so
%{_libdir}/%{name}/plugins/relay.so
#{_libdir}/%%{name}/plugins/rmodifier.so
%{_libdir}/%{name}/plugins/script.so
%{_libdir}/%{name}/plugins/trigger.so
%{_libdir}/%{name}/plugins/typing.so
%{_libdir}/%{name}/plugins/xfer.so
%{_iconsdir}/hicolor/*/apps/%{name}.png

#--------------------------------------------------------------------

%package perl
Group:		Networking/IRC
Summary: 	Weechat perl plugins
Requires:	%{name} = %{version}

%description perl
This package allow weechat to use perl scripts

%files perl
%{_libdir}/%{name}/plugins/perl.so

#--------------------------------------------------------------------

%package python
Group:		Networking/IRC
Summary:	Weechat python plugins
Requires:	%{name} = %{version}

%description python
This package allow weechat to use python scripts

%files python
%{_libdir}/%{name}/plugins/python.so

#--------------------------------------------------------------------

%package guile
Group:          Networking/IRC
Summary:        Weechat guile plugins
Requires:       %{name} = %{version}

%description guile
This package allow weechat to use guile scripts

%files guile
%{_libdir}/%{name}/plugins/guile.so

#--------------------------------------------------------------------

%package tcl
Group:		Networking/IRC
Summary:	Weechat tcl plugins
Requires:	%{name} = %{version}

%description tcl
This package allow weechat to use tcl scripts

%files tcl
%{_libdir}/%{name}/plugins/tcl.so

#--------------------------------------------------------------------

%package ruby
Group:		Networking/IRC
Summary:	Weechat ruby plugins
Requires:	%{name} = %{version}

%description ruby
This package allow weechat to use ruby scripts

%files ruby
%{_libdir}/%{name}/plugins/ruby.so

#--------------------------------------------------------------------

%package lua
Group:		Networking/IRC
Summary:	Weechat lua plugins
Requires:	%{name} = %{version}

%description lua
This package allow weechat to use lua scripts

%files lua
%{_libdir}/%{name}/plugins/lua.so

#--------------------------------------------------------------------

%package charset
Group:		Networking/IRC
Summary:	Weechat charset plugins
Requires:	%{name} = %{version}

%description charset
This package allow weechat to use charset

%files charset
%{_libdir}/%{name}/plugins/charset.so

#--------------------------------------------------------------------

%package aspell
Group:		Networking/IRC
Summary:	Weechat spell check plugins
Requires:	%{name} = %{version}

%description aspell
This package allow weechat to use spell checker feature.

%files aspell
%{_libdir}/%{name}/plugins/spell.so

#--------------------------------------------------------------------

%package  devel
Summary:	Development files for weechat
Group:		Development/C
Requires:	%{name} = %{version}-%{release}

%description devel
WeeChat (Wee Enhanced Environment for Chat) is a portable, fast, light and
extensible IRC client. Everything can be done with a keyboard.
It is customizable and extensible with scripts.

This package contains include files and pc file for weechat.

%files devel
%{_includedir}/%{name}
%{_libdir}/pkgconfig/%{name}.pc

#--------------------------------------------------------------------

%prep
%autosetup -p1 -n %{name}-%{version}%{?prel:-%prel}

%build
%cmake \
	-DPREFIX=%{_prefix} \
	-DLIBDIR=%{_libdir} \
	-DENABLE_ENCHANT=ON \
	-DENABLE_MAN=ON \
	-DENABLE_JAVASCRIPT=OFF \
	-DCA_FILE=/etc/pki/tls/certs/ca-bundle.crt \
	-DENABLE_PHP=OFF
%cmake_build

asciidoctor *.adoc

%install
%cmake_install

%find_lang %{name} --all-name --with-man


%changelog
* Wed Jul 24 2024 kekepower <kekepower> 4.3.5-1.mga10
+ Revision: 2082429
- Update to version 4.3.5

* Thu Jul 04 2024 kekepower <kekepower> 4.3.4-1.mga10
+ Revision: 2079744
- Update to version 4.3.4

* Sat Jun 22 2024 kekepower <kekepower> 4.3.3-1.mga10
+ Revision: 2076202
- Update to version 4.3.3

* Fri Jun 07 2024 kekepower <kekepower> 4.3.2-1.mga10
+ Revision: 2070472
- Update to version 4.3.2

* Sat Jun 01 2024 kekepower <kekepower> 4.3.1-1.mga10
+ Revision: 2069023
- Update to version 4.3.1

* Sun May 26 2024 kekepower <kekepower> 4.3.0-1.mga10
+ Revision: 2067697
- Update to version 4.3.0

* Tue Apr 09 2024 kekepower <kekepower> 4.2.2-1.mga10
+ Revision: 2056267
- Update to version 4.2.2

* Sun Mar 24 2024 kekepower <kekepower> 4.2.1-1.mga10
+ Revision: 2051874
- Update to version 4.2.1

* Sun Jan 21 2024 kekepower <kekepower> 4.2.0-1.mga10
+ Revision: 2033323
- Update to version 4.2.0

* Fri Dec 29 2023 daviddavid <daviddavid> 4.1.2-2.mga10
+ Revision: 2023928
- rebuild for py3.12 and new perl

* Mon Dec 04 2023 kekepower <kekepower> 4.1.2-1.mga10
+ Revision: 2012922
- Update to version 4.1.2

* Fri Oct 27 2023 kekepower <kekepower> 4.1.1-1.mga10
+ Revision: 2002060
- Update to version 4.1.1

* Fri Oct 20 2023 kekepower <kekepower> 4.1.0-1.mga10
+ Revision: 1999654
- Update to version 4.1.0

* Sun Sep 24 2023 kekepower <kekepower> 4.0.5-1.mga10
+ Revision: 1990337
- Update to version 4.0.5

* Mon Aug 28 2023 kekepower <kekepower> 4.0.4-1.mga10
+ Revision: 1980611
- Update to version 4.0.4

* Mon Jun 26 2023 kekepower <kekepower> 4.0.0-1.mga9
+ Revision: 1963076
- Update to version 4.0.0

* Sun Jan 08 2023 kekepower <kekepower> 3.8-1.mga9
+ Revision: 1931517
- Update to version 3.8

* Fri Oct 21 2022 kekepower <kekepower> 3.7.1-1.mga9
+ Revision: 1898189
- Update to version 3.7.1

* Sun Oct 09 2022 kekepower <kekepower> 3.7-1.mga9
+ Revision: 1895871
- Update to version 3.7

* Mon Jul 11 2022 kekepower <kekepower> 3.6-1.mga9
+ Revision: 1868400
- Update to version 3.6

* Tue Jun 07 2022 umeabot <umeabot> 3.5-2.mga9
+ Revision: 1862783
- Rebuild for Perl 5.36

* Sun Mar 27 2022 kekepower <kekepower> 3.5-1.mga9
+ Revision: 1829219
- Update to version 3.5

* Mon Mar 21 2022 kekepower <kekepower> 3.4.1-1.mga9
+ Revision: 1812422
- Update to version 3.4.1

* Fri Feb 25 2022 pterjan <pterjan> 3.4-3.mga9
+ Revision: 1784641
- Rebuild for Ruby 3.1

* Mon Feb 14 2022 tmb <tmb> 3.4-2.mga9
+ Revision: 1774858
- rebuild for python 3.10

* Fri Dec 24 2021 kekepower <kekepower> 3.4-1.mga9
+ Revision: 1763567
- Update to version 3.4

* Sun Sep 19 2021 kekepower <kekepower> 3.3-1.mga9
+ Revision: 1745944
- Update to version 3.3

* Mon Sep 06 2021 kekepower <kekepower> 3.2.1-1.mga9
+ Revision: 1744383
- Update to version 3.2.1
- Update to version 3.2

* Mon May 24 2021 umeabot <umeabot> 3.1-4.mga9
+ Revision: 1727388
- Rebuild for perl 5.34

* Fri Apr 02 2021 wally <wally> 3.1-3.mga9
+ Revision: 1712741
- rebuild with lua 5.4
- drop old conflicts

* Wed Mar 24 2021 daviddavid <daviddavid> 3.1-2.mga9
+ Revision: 1708562
- rebuild for python 3.9

* Sun Mar 07 2021 kekepower <kekepower> 3.1-1.mga9
+ Revision: 1700406
- Update to version 3.1

* Sun Mar 07 2021 kekepower <kekepower> 3.1-0.rc1.1.mga9
+ Revision: 1700377
- Update to version 3.1rc1

* Tue Mar 02 2021 kekepower <kekepower> 3.0.1-1.mga9
+ Revision: 1696270
- Update to version 3.0.1

* Fri Nov 13 2020 kekepower <kekepower> 3.0-1.mga8
+ Revision: 1645036
- Update to version 3.0 final

* Sat Nov 07 2020 wally <wally> 3.0-0.rc1.1.mga8
+ Revision: 1643489
- new version 3.0-rc1
- switch to guile3.0

* Mon Jul 27 2020 kekepower <kekepower> 2.9-1.mga8
+ Revision: 1609318
- Update to version 2.9

* Wed Jun 17 2020 umeabot <umeabot> 2.8-2.mga8
+ Revision: 1595326
- Rebuild for perl 5.32

* Sun Mar 29 2020 kekepower <kekepower> 2.8-1.mga8
+ Revision: 1562145
- Update to version 2.8

* Mon Mar 02 2020 pterjan <pterjan> 2.7.1-2.mga8
+ Revision: 1553187
- Rebuild for ruby 2.7

* Fri Feb 28 2020 kekepower <kekepower> 2.7.1-1.mga8
+ Revision: 1552021
- Update to version 2.7.1
 o irc: fix crash when receiving a malformed message 324 (channel mode) (CVE-2020-8955) (mga#26267)

* Tue Feb 18 2020 umeabot <umeabot> 2.7-2.mga8
+ Revision: 1539875
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Fri Dec 13 2019 kekepower <kekepower> 2.7-1.mga8
+ Revision: 1466644
- Update to version 2.7

* Sun Sep 15 2019 kekepower <kekepower> 2.6-1.mga8
+ Revision: 1440969
- Switch to Python 3
- Update to version 2.6

* Tue Aug 27 2019 tmb <tmb> 2.5-2.mga8
+ Revision: 1433964
- rebuild for perl 5.30

* Sat Jun 29 2019 kekepower <kekepower> 2.5-1.mga8
+ Revision: 1415899
- Update to version 2.5

* Fri Feb 22 2019 wally <wally> 2.4-2.mga7
+ Revision: 1369377
- switch to enchant2

* Sun Feb 17 2019 kekepower <kekepower> 2.4-1.mga7
+ Revision: 1367859
- Update to version 2.4

* Fri Nov 02 2018 kekepower <kekepower> 2.3-1.mga7
+ Revision: 1327759
- Update to version 2.3

* Tue Oct 02 2018 wally <wally> 2.2-1.mga7
+ Revision: 1315656
- new version 2.2
- switch to lua5.3

* Sun Sep 23 2018 umeabot <umeabot> 2.1-3.mga7
+ Revision: 1301661
- Mageia 7 Mass Rebuild

* Tue Aug 07 2018 daviddavid <daviddavid> 2.1-2.mga7
+ Revision: 1248809
- rebuild for new perl 5.28.0

* Thu Jun 07 2018 wally <wally> 2.1-1.mga7
+ Revision: 1235208
- new version 2.1

* Mon Jan 01 2018 wally <wally> 2.0.1-1.mga7
+ Revision: 1188866
- new version 2.0.1

* Mon Jan 01 2018 pterjan <pterjan> 1.9.1-2.mga7
+ Revision: 1188718
- Rebuild for Ruby 2.5

* Fri Oct 06 2017 mrambo3501 <mrambo3501> 1.9.1-1.mga7
+ Revision: 1169579
- version 1.9.1 fixes CVE-2017-14727 mga#21802

* Tue Aug 15 2017 pterjan <pterjan> 1.9-3.mga7
+ Revision: 1140907
- Rebuild for new Ruby

* Sat Jul 22 2017 neoclust <neoclust> 1.9-2.mga7
+ Revision: 1126634
- Rebuild against new Perl 5.26

* Fri Jul 21 2017 wally <wally> 1.9-1.mga7
+ Revision: 1126386
- new version 1.9

* Sat Apr 29 2017 neoclust <neoclust> 1.7.1-1.mga6
+ Revision: 1098076
- New version 1.7.1 - Fixes CVE-2017-8073 (mga#20756)

* Tue Jan 17 2017 wally <wally> 1.7-1.mga6
+ Revision: 1082173
- new version 1.7
- build guile plugin

* Wed Jan 11 2017 wally <wally> 1.6-1.mga6
+ Revision: 1081117
- new version 1.6
- drop unneeded patches and rediff others

* Mon Jan 11 2016 luigiwalser <luigiwalser> 0.4.1-12.mga6
+ Revision: 921844
- rebuild for gnutls

* Wed Oct 28 2015 ycantin <ycantin> 0.4.1-11.mga6
+ Revision: 895928
- rebuild for ruby 2.2

* Mon Oct 05 2015 daviddavid <daviddavid> 0.4.1-10.mga6
+ Revision: 886313
- rebuild for new tcl 8.6.4

* Mon Sep 14 2015 fwang <fwang> 0.4.1-9.mga6
+ Revision: 879227
- rebuild for new libgcrypt

* Sat Jun 27 2015 tv <tv> 0.4.1-8.mga6
+ Revision: 846067
- rebuild for soname-ifed perl

* Wed Oct 15 2014 umeabot <umeabot> 0.4.1-7.mga5
+ Revision: 740101
- Second Mageia 5 Mass Rebuild

* Tue Oct 07 2014 tv <tv> 0.4.1-6.mga5
+ Revision: 737421
- rebuild for missing pythoneggs deps
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.4.1-4.mga4
+ Revision: 535875
- Mageia 4 Mass Rebuild

* Sat Sep 21 2013 fwang <fwang> 0.4.1-3.mga4
+ Revision: 482772
- there is no info files

* Sat Sep 21 2013 fwang <fwang> 0.4.1-2.mga4
+ Revision: 482719
- update file list
- sync with fedora patch
- rebuild for ruby 2.0

* Fri Jun 28 2013 dams <dams> 0.4.1-1.mga4
+ Revision: 448076
- new version 0.4.1
- clean specfile

* Mon Jan 14 2013 umeabot <umeabot> 0.3.9.2-2.mga3
+ Revision: 385674
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 30 2012 fwang <fwang> 0.3.9.2-1.mga3
+ Revision: 323338
- new version 0.3.9.2

* Sun Nov 11 2012 fwang <fwang> 0.3.9.1-1.mga3
+ Revision: 316952
- update file list
- disable aspell support
- new version 0.3.9.1
- enable aspell

* Wed Sep 12 2012 fwang <fwang> 0.3.8-1.mga3
+ Revision: 292576
- sync patch from fedora
- use lua 5.1
- add br
- new version 0.3.8

* Fri Dec 16 2011 fwang <fwang> 0.3.6-3.mga2
+ Revision: 182527
- update summary
- rediff enchant patches

* Fri Dec 16 2011 fwang <fwang> 0.3.6-2.mga2
+ Revision: 182381
- conflicts with older package

* Fri Dec 16 2011 fwang <fwang> 0.3.6-1.mga2
+ Revision: 182369
- update file list
- new version 0.3.6
- rebuild for new gnutls

* Wed Jul 06 2011 fwang <fwang> 0.3.5-2.mga2
+ Revision: 119166
- rebuild for new tcl

* Wed Jul 06 2011 dams <dams> 0.3.5-1.mga2
+ Revision: 119113
- add patch
- update to 0.3.5
- rediff patch
- update BR
- clean spec

* Sun May 08 2011 grenoya <grenoya> 0.3.0-1.mga1
+ Revision: 96453
- add patch from Fedora for python2.7
- imported package weechat

